summaryrefslogtreecommitdiff
path: root/.emacs.d
diff options
context:
space:
mode:
authordefanor <defanor@uberspace.net>2017-09-06 23:01:22 +0300
committerdefanor <defanor@uberspace.net>2017-09-06 23:01:22 +0300
commit90c144467eb67e1a020f51443613a3af133cff52 (patch)
treeaf3c217285a99ec5d62c2e1858585e09cc6db9ff /.emacs.d
parentb0ae44efb8fe5188b387b1524a86388d361fb1fe (diff)
Specify w3m-haddock-heading-face in blueish-theme
Diffstat (limited to '.emacs.d')
-rw-r--r--.emacs.d/blueish-theme.el82
1 files changed, 42 insertions, 40 deletions
diff --git a/.emacs.d/blueish-theme.el b/.emacs.d/blueish-theme.el
index 632d751..7d30cc0 100644
--- a/.emacs.d/blueish-theme.el
+++ b/.emacs.d/blueish-theme.el
@@ -26,49 +26,51 @@
"A blueish theme")
(custom-theme-set-faces
- 'blueish
+ 'blueish
- ;; ----------------- Frame stuff --------------------
- `(default ((((type graphic)) (:background "#091419" :foreground "#c0d0d6"))))
- `(cursor ((t (:background "#F8F8F0"))))
- `(hl-line ((t (:background "#666666"))))
- `(modeline ((t (:background "#183c66" :foreground "white"))))
- '(mode-line-inactive ((t (:background "#2f2f3b" :foreground "#d0dfe6" :box nil))))
- `(mode-line ((t (:box nil :foreground "white" :background "#183c66"))))
- `(fringe ((((type graphic)) (:background "#14191f"))))
- ;; Dir-ed search prompt
- `(minibuffer-prompt ((default (:foreground "white"))))
- ;; Highlight region color
- `(region ((t (:foreground "#FFE792" :background "#1b232c"))))
+ ;; ----------------- Frame stuff --------------------
+ '(default ((((type graphic)) (:background "#091419" :foreground "#c0d0d6"))))
+ '(cursor ((t (:background "#F8F8F0"))))
+ '(hl-line ((t (:background "#666666"))))
+ '(modeline ((t (:background "#183c66" :foreground "white"))))
+ '(mode-line-inactive ((t (:background "#2f2f3b" :foreground "#d0dfe6" :box nil))))
+ '(mode-line ((t (:box nil :foreground "white" :background "#183c66"))))
+ '(fringe ((((type graphic)) (:background "#14191f"))))
+ ;; Dir-ed search prompt
+ '(minibuffer-prompt ((default (:foreground "white"))))
+ ;; Highlight region color
+ '(region ((t (:foreground "#FFE792" :background "#1b232c"))))
- ;; ---------------- Code Highlighting ---------------
- ;; Builtin
- `(font-lock-builtin-face ((t (:foreground "#6ee2ff"))))
- ;; Comments
- `(font-lock-comment-face ((t (:foreground "#709999"))))
- ;; Function names
- `(font-lock-function-name-face ((t (:foreground "#effbff"))))
- ;; Keywords
- `(font-lock-keyword-face ((t (:foreground "#748aa6"))))
- ;; Strings
- `(font-lock-string-face ((t (:foreground "#6ea0d0"))))
- ;; Variables
- `(font-lock-variable-name-face ((t (:foreground "#d0dfe6"))))
- `(font-lock-type-face ((t (:foreground "#95cc5e"))))
- `(font-lock-warning-face ((t (:foreground "white" :bold t))))
+ ;; ---------------- Code Highlighting ---------------
+ ;; Builtin
+ '(font-lock-builtin-face ((t (:foreground "#6ee2ff"))))
+ ;; Comments
+ '(font-lock-comment-face ((t (:foreground "#709999"))))
+ ;; Function names
+ '(font-lock-function-name-face ((t (:foreground "#effbff"))))
+ ;; Keywords
+ '(font-lock-keyword-face ((t (:foreground "#748aa6"))))
+ ;; Strings
+ '(font-lock-string-face ((t (:foreground "#6ea0d0"))))
+ ;; Variables
+ '(font-lock-variable-name-face ((t (:foreground "#d0dfe6"))))
+ '(font-lock-type-face ((t (:foreground "#95cc5e"))))
+ '(font-lock-warning-face ((t (:foreground "white" :bold t))))
- ;; ---------------- Package Specific Stuff -----------
- ;; circe
- `(circe-my-message-face ((t (:foreground "#d0ffff"))))
- ;; ido
- `(ido-only-match ((t (:foreground "#66ff66"))))
- `(ido-subdir ((t (:foreground "#ffaaaa"))))
- ;; mail
- `(message-header-name ((t (:foreground "#66FF99"))))
- ;; w3m
- '(w3m-form ((t (:foreground "#ffdddd" :underline t))))
- '(w3m-form-button ((t (:background "#363b40" :foreground "#c0c4c8" :box (:line-width 2 :color "#202020" :style released-button)))))
- )
+ ;; ---------------- Package Specific Stuff -----------
+ ;; circe
+ '(circe-my-message-face ((t (:foreground "#d0ffff"))))
+ ;; ido
+ '(ido-only-match ((t (:foreground "#66ff66"))))
+ '(ido-subdir ((t (:foreground "#ffaaaa"))))
+ ;; mail
+ '(message-header-name ((t (:foreground "#66FF99"))))
+ ;; w3m
+ '(w3m-form ((t (:foreground "#ffdddd" :underline t))))
+ '(w3m-form-button ((t (:background "#363b40" :foreground "#c0c4c8" :box (:line-width 2 :color "#202020" :style released-button)))))
+ ;; w3m-haddock
+ '(w3m-haddock-heading-face ((t (:background "#1b2025"))))
+ )
;;;###Autoload